[Libreoffice-commits] core.git: framework/source

Andrea Gelmini andrea.gelmini at gelma.net
Wed Sep 30 05:39:23 PDT 2015


 framework/source/fwi/classes/protocolhandlercache.cxx |    2 
 framework/source/fwi/jobs/configaccess.cxx            |    2 
 framework/source/helper/oframes.cxx                   |    2 
 framework/source/helper/persistentwindowstate.cxx     |    2 
 framework/source/helper/statusindicatorfactory.cxx    |   10 +--
 framework/source/inc/loadenv/actionlockguard.hxx      |    4 -
 framework/source/inc/loadenv/loadenv.hxx              |    2 
 framework/source/jobs/helponstartup.cxx               |    2 
 framework/source/jobs/jobdispatch.cxx                 |   12 ++--
 framework/source/layoutmanager/helpers.cxx            |    2 
 framework/source/layoutmanager/layoutmanager.cxx      |    2 
 framework/source/loadenv/loadenv.cxx                  |    4 -
 framework/source/recording/dispatchrecorder.cxx       |    2 
 framework/source/services/autorecovery.cxx            |   52 +++++++++---------
 framework/source/services/desktop.cxx                 |   10 +--
 15 files changed, 55 insertions(+), 55 deletions(-)

New commits:
commit eab0904f0edda70334532b5cbf466717966f5db0
Author: Andrea Gelmini <andrea.gelmini at gelma.net>
Date:   Tue Sep 29 17:53:53 2015 +0200

    Fix typos
    
    Change-Id: I81f6f356c1a6873fcc9a3bde487127b673fa9a61
    Reviewed-on: https://gerrit.libreoffice.org/18952
    Reviewed-by: Oliver Specht <oliver.specht at cib.de>
    Tested-by: Oliver Specht <oliver.specht at cib.de>

diff --git a/framework/source/fwi/classes/protocolhandlercache.cxx b/framework/source/fwi/classes/protocolhandlercache.cxx
index 9d71c8c..46a4266 100644
--- a/framework/source/fwi/classes/protocolhandlercache.cxx
+++ b/framework/source/fwi/classes/protocolhandlercache.cxx
@@ -74,7 +74,7 @@ sal_Int32    HandlerCache::m_nRefCount = 0;
 HandlerCFGAccess* HandlerCache::m_pConfig = NULL;
 
 /**
-    @short      ctor of the cache of all registered protoco handler
+    @short      ctor of the cache of all registered protocol handler
     @descr      It tries to open the right configuration package automatically
                 and fill the internal structures. After that the cache can be
                 used for read access on this data and perform some search
diff --git a/framework/source/fwi/jobs/configaccess.cxx b/framework/source/fwi/jobs/configaccess.cxx
index bacc8c1..08dac55 100644
--- a/framework/source/fwi/jobs/configaccess.cxx
+++ b/framework/source/fwi/jobs/configaccess.cxx
@@ -82,7 +82,7 @@ ConfigAccess::EOpenMode ConfigAccess::getMode() const
             which needs cfg access, can use it. That prevent us against multiple open/close requests.
             But you can use this method to upgrade an already opened configuration too.
             It's possible to open a config access in READONLY mode first and "open" it at a second
-            time within the mode READWRITE. Then we will upgrade it. Dowgrade will be possible too.
+            time within the mode READWRITE. Then we will upgrade it. Downgrade will be possible too.
 
             But note: closing will be done explicitly by calling method close() ... not by
             downgrading with mode CLOSED!
diff --git a/framework/source/helper/oframes.cxx b/framework/source/helper/oframes.cxx
index 18f92f8..224d155 100644
--- a/framework/source/helper/oframes.cxx
+++ b/framework/source/helper/oframes.cxx
@@ -196,7 +196,7 @@ Sequence< css::uno::Reference< XFrame > > SAL_CALL OFrames::queryFrames( sal_Int
     // Else; Do nothing! Our owner is dead.
     SAL_WARN_IF( !xOwner.is(), "fwk", "OFrames::queryFrames(): Our owner is dead - you can't query for frames ...!" );
 
-    // Resturn result of this operation.
+    // Return result of this operation.
     return seqFrames;
 }
 
diff --git a/framework/source/helper/persistentwindowstate.cxx b/framework/source/helper/persistentwindowstate.cxx
index 565aaab..afef67b 100644
--- a/framework/source/helper/persistentwindowstate.cxx
+++ b/framework/source/helper/persistentwindowstate.cxx
@@ -275,7 +275,7 @@ void PersistentWindowState::implst_setWindowStateOnWindow(const css::uno::Refere
     SystemWindow* pSystemWindow = static_cast<SystemWindow*>(pWindow);
     WorkWindow*   pWorkWindow   = static_cast<WorkWindow*  >(pWindow);
 
-    // dont save this special state!
+    // don't save this special state!
     if (pWorkWindow->IsMinimized())
         return;
 
diff --git a/framework/source/helper/statusindicatorfactory.cxx b/framework/source/helper/statusindicatorfactory.cxx
index 44e88f0..4b902cd 100644
--- a/framework/source/helper/statusindicatorfactory.cxx
+++ b/framework/source/helper/statusindicatorfactory.cxx
@@ -165,8 +165,8 @@ void StatusIndicatorFactory::reset(const css::uno::Reference< css::task::XStatus
     aReadLock.clear();
     // <- SAFE ----------------------------------
 
-    // not the top most child => dont change UI
-    // But dont forget Reschedule!
+    // not the top most child => don't change UI
+    // But don't forget Reschedule!
     if (
         (xChild == xActive) &&
         (xProgress.is()   )
@@ -246,7 +246,7 @@ void StatusIndicatorFactory::setText(const css::uno::Reference< css::task::XStat
     // SAFE -> ----------------------------------
 
     // paint only the top most indicator
-    // but dont forget to Reschedule!
+    // but don't forget to Reschedule!
     if (
         (xChild == xActive) &&
         (xProgress.is()   )
@@ -311,7 +311,7 @@ void StatusIndicatorFactory::implts_makeParentVisibleIfAllowed()
     else
         xParentWindow = xPluggWindow;
 
-    // dont disturb user in case he put the loading document into the background!
+    // don't disturb user in case he put the loading document into the background!
     // Suppress any setVisible() or toFront() call in case the initial show was
     // already made.
     css::uno::Reference< css::awt::XWindow2 > xVisibleCheck(xParentWindow, css::uno::UNO_QUERY);
@@ -344,7 +344,7 @@ void StatusIndicatorFactory::implts_makeParentVisibleIfAllowed()
     // We need a Hack for our applications: They get her progress from the frame directly
     // on saving documents. Because there is no progress set on the MediaDescriptor.
     // But that's wrong. In case the document was opened hidden, they should not use any progress .-(
-    // They only possible workaround: dont show the parent window here, if the document was opened hidden.
+    // They only possible workaround: don't show the parent window here, if the document was opened hidden.
     bool bHiddenDoc = false;
     if (xFrame.is())
     {
diff --git a/framework/source/inc/loadenv/actionlockguard.hxx b/framework/source/inc/loadenv/actionlockguard.hxx
index 9a55f1c..8f72381 100644
--- a/framework/source/inc/loadenv/actionlockguard.hxx
+++ b/framework/source/inc/loadenv/actionlockguard.hxx
@@ -29,7 +29,7 @@ namespace framework{
             <type scope="com::sun::star::document">XActionLockable</type>.
 
     @descr  This guard should be used to be sure, that any lock will be
-            released. Otherwise the locaked document can hinder the office on shutdown!
+            released. Otherwise the locked document can hinder the office on shutdown!
 */
 class ActionLockGuard
 {
@@ -141,7 +141,7 @@ class ActionLockGuard
             if (m_bActionLocked && m_xActionLock.is())
             {
                 m_xActionLock->removeActionLock();
-                // dont check for any locks here ...
+                // don't check for any locks here ...
                 // May another guard use the same lock object :-(
                 m_bActionLocked = false;
             }
diff --git a/framework/source/inc/loadenv/loadenv.hxx b/framework/source/inc/loadenv/loadenv.hxx
index d2fa915..a5513b5 100644
--- a/framework/source/inc/loadenv/loadenv.hxx
+++ b/framework/source/inc/loadenv/loadenv.hxx
@@ -180,7 +180,7 @@ private:
     /** @short  holds the information about the finished load process.
 
         @descr  The content of m_xTargetFrame can't be used as valid indicator,
-                (in case the micht existing old document was reactivated)
+                (in case the existing old document was reactivated)
                 we must hold the result of the load process explicitly.
      */
     bool m_bLoaded;
diff --git a/framework/source/jobs/helponstartup.cxx b/framework/source/jobs/helponstartup.cxx
index 9684810..eb31a94 100644
--- a/framework/source/jobs/helponstartup.cxx
+++ b/framework/source/jobs/helponstartup.cxx
@@ -112,7 +112,7 @@ css::uno::Any SAL_CALL HelpOnStartup::execute(const css::uno::Sequence< css::bea
     // classify it's used application module.
     OUString sModule = its_getModuleIdFromEnv(lArguments);
 
-    // Attention: We are bound to events for openeing any document inside the office.
+    // Attention: we are bound to events for opening any document inside the office.
     // That includes e.g. the help module itself. But we have to do nothing then!
     if (sModule.isEmpty())
         return css::uno::Any();
diff --git a/framework/source/jobs/jobdispatch.cxx b/framework/source/jobs/jobdispatch.cxx
index 693a675..6ec543b 100644
--- a/framework/source/jobs/jobdispatch.cxx
+++ b/framework/source/jobs/jobdispatch.cxx
@@ -318,9 +318,9 @@ void JobDispatch::impl_dispatchEvent( /*IN*/ const OUString&
 
     css::uno::Reference< css::frame::XDispatchResultListener > xThis( static_cast< ::cppu::OWeakObject* >(this), css::uno::UNO_QUERY );
 
-    // no jobs ... no execution
-    // But a may given listener will know something ...
-    // I think this operaton was finished successfully.
+    // no jobs... no execution
+    // But a may given listener will know something...
+    // I think this operation was finished successfully.
     // It's not really an error, if no registered jobs could be located.
     // Step over all found jobs and execute it
     int nExecutedJobs=0;
@@ -350,7 +350,7 @@ void JobDispatch::impl_dispatchEvent( /*IN*/ const OUString&
             continue;
 
         // Special mode for listener.
-        // We dont notify it directly here. We delegate that
+        // We don't notify it directly here. We delegate that
         // to the job implementation. But we must set ourself there too.
         // Because this job must fake the source address of the event.
         // Otherwise the listener may ignore it.
@@ -411,7 +411,7 @@ void JobDispatch::impl_dispatchService( /*IN*/ const OUString&
     css::uno::Reference< css::frame::XDispatchResultListener > xThis( static_cast< ::cppu::OWeakObject* >(this), css::uno::UNO_QUERY );
 
     // Special mode for listener.
-    // We dont notify it directly here. We delegate that
+    // We don't notify it directly here. We delegate that
     // to the job implementation. But we must set ourself there too.
     // Because this job must fake the source address of the event.
     // Otherwise the listener may ignore it.
@@ -461,7 +461,7 @@ void JobDispatch::impl_dispatchAlias( /*IN*/ const OUString&
     css::uno::Reference< css::frame::XDispatchResultListener > xThis( static_cast< ::cppu::OWeakObject* >(this), css::uno::UNO_QUERY );
 
     // Special mode for listener.
-    // We dont notify it directly here. We delegate that
+    // We don't notify it directly here. We delegate that
     // to the job implementation. But we must set ourself there too.
     // Because this job must fake the source address of the event.
     // Otherwise the listener may ignore it.
diff --git a/framework/source/layoutmanager/helpers.cxx b/framework/source/layoutmanager/helpers.cxx
index 6ea1c83..5fdbf9a 100644
--- a/framework/source/layoutmanager/helpers.cxx
+++ b/framework/source/layoutmanager/helpers.cxx
@@ -285,7 +285,7 @@ bool implts_isFrameOrWindowTop( const uno::Reference< frame::XFrame >& xFrame )
     if (xFrame->isTop())
         return true;
 
-    uno::Reference< awt::XTopWindow > xWindowCheck(xFrame->getContainerWindow(), uno::UNO_QUERY); // dont use _THROW here ... it's a check only
+    uno::Reference< awt::XTopWindow > xWindowCheck(xFrame->getContainerWindow(), uno::UNO_QUERY); // don't use _THROW here ... it's a check only
     if (xWindowCheck.is())
     {
         // #i76867# top and system window is required.
diff --git a/framework/source/layoutmanager/layoutmanager.cxx b/framework/source/layoutmanager/layoutmanager.cxx
index a662ce8..a14b7ab 100644
--- a/framework/source/layoutmanager/layoutmanager.cxx
+++ b/framework/source/layoutmanager/layoutmanager.cxx
@@ -948,7 +948,7 @@ void LayoutManager::implts_backupProgressBarWrapper()
 
 void LayoutManager::implts_destroyProgressBar()
 {
-    // dont remove the progressbar in general
+    // don't remove the progressbar in general
     // We must reuse it if a new status bar is created later.
     // Of course there exists one backup only.
     // And further this backup will be released inside our dtor.
diff --git a/framework/source/loadenv/loadenv.cxx b/framework/source/loadenv/loadenv.cxx
index 2a7e6e8..ffbd899 100644
--- a/framework/source/loadenv/loadenv.cxx
+++ b/framework/source/loadenv/loadenv.cxx
@@ -1528,7 +1528,7 @@ void LoadEnv::impl_reactForLoadingState()
     {
         // Bring the new loaded document to front (if allowed!).
         // Note: We show new created frames here only.
-        // We dont hide already visible frames here ...
+        // We don't hide already visible frames here ...
         css::uno::Reference< css::awt::XWindow > xWindow      = m_xTargetFrame->getContainerWindow();
         bool                                 bHidden      = m_lMediaDescriptor.getUnpackedValueOrDefault(utl::MediaDescriptor::PROP_HIDDEN(), false);
         bool                                 bMinimized = m_lMediaDescriptor.getUnpackedValueOrDefault(utl::MediaDescriptor::PROP_MINIMIZED(), false);
@@ -1700,7 +1700,7 @@ void LoadEnv::impl_applyPersistentWindowState(const css::uno::Reference< css::aw
     if (!bSystemWindow && !bWorkWindow)
         return;
 
-    // dont overwrite this special state!
+    // don't overwrite this special state!
     WorkWindow* pWorkWindow = static_cast<WorkWindow*>(pWindow);
     if (pWorkWindow->IsMinimized())
         return;
diff --git a/framework/source/recording/dispatchrecorder.cxx b/framework/source/recording/dispatchrecorder.cxx
index 927c335..85b089b 100644
--- a/framework/source/recording/dispatchrecorder.cxx
+++ b/framework/source/recording/dispatchrecorder.cxx
@@ -28,7 +28,7 @@ using namespace ::com::sun::star::uno;
 
 namespace framework{
 
-// used to mark a dispatch as comment (mostly it indicates an error) Changing of this wdefine will impact all using of such comments ...
+// used to mark a dispatch as comment (mostly it indicates an error) Changing of this define will impact all using of such comments...
 #define REM_AS_COMMENT    "rem "
 
 //  XInterface, XTypeProvider, XServiceInfo
diff --git a/framework/source/services/desktop.cxx b/framework/source/services/desktop.cxx
index 79d2517..7a5a711 100644
--- a/framework/source/services/desktop.cxx
+++ b/framework/source/services/desktop.cxx
@@ -253,7 +253,7 @@ sal_Bool SAL_CALL Desktop::terminate()
     // Order of called listener is important!
     // Some of them are harmless,-)
     // but some can be dangerous. E.g. it would be dangerous if we close our pipe
-    // and dont terminate in real because another listener throws a veto exception .-)
+    // and don't terminate in real because another listener throws a veto exception .-)
 
     bool bTerminate = false;
     try
@@ -1027,7 +1027,7 @@ void SAL_CALL Desktop::disposing()
 
     // Now - we are alone and its the first call of this method ...
     // otherwise call before had thrown a DisposedException / hopefully .-)
-    // But we dont use the transaction object created before ... we reset it immediately ...
+    // But we don't use the transaction object created before ... we reset it immediately ...
     // two lines of code ... for what ?
     // The answer: We wished to synchronize concurrent dispose() calls -> OK
     // But next line will wait for all currently running transaction (even if they
@@ -1087,7 +1087,7 @@ void SAL_CALL Desktop::disposing()
                 about our dying!
                 You must release this listener reference during your own disposing() method.
 
-    @attention  Our container is threadsafe himeslf. So we don't need any lock here.
+    @attention  Our container is threadsafe himself. So we don't need any lock here.
     @param      "xListener", reference to valid listener. We don't accept invalid values!
     @threadsafe yes
 */
@@ -1194,7 +1194,7 @@ void SAL_CALL Desktop::handle( const css::uno::Reference< css::task::XInteractio
     // get packed request and work on it first
     // Attention: Don't set it on internal member BEFORE interaction is finished - because
     // "loadComponentFromURL()" yield tills this member is changed. If we do it before
-    // interaction finish we can't guarantee right functionality. May be we cancel load process to erliear ...
+    // interaction finish we can't guarantee right functionality. May be we cancel load process to earliear...
     css::uno::Any aRequest = xRequest->getRequest();
 
     // extract continuations from request
@@ -1724,7 +1724,7 @@ bool Desktop::impl_closeFrames(bool bAllowUI)
                 catch(const css::util::CloseVetoException&)
                 {
                     // Any internal process of this frame disagree with our request.
-                    // Safe this state but dont break these loop. Other frames has to be closed!
+                    // Safe this state but don't break these loop. Other frames has to be closed!
                     ++nNonClosedFrames;
 
                     // Reactivate controller.


More information about the Libreoffice-commits mailing list
diff --git a/framework/source/services/autorecovery.cxx b/framework/source/services/autorecovery.cxx
index 39110f7..8967ea9 100644
--- a/framework/source/services/autorecovery.cxx
+++ b/framework/source/services/autorecovery.cxx
@@ -234,7 +234,7 @@ public:
         /** timer must be started with a very(!) short time interval,
             to poll for the end of an user action, which does not allow saving documents in general */
         E_POLL_TILL_AUTOSAVE_IS_ALLOWED,
         /** dont start the timer - but calls the same action then before immediately again! */
         E_CALL_ME_BACK
     };
 
@@ -421,7 +421,7 @@ private:
 
                 And further it's not possible to use a simple boolean value here.
                 Because if more than one operation iterates over the same stl container ...
-                (only to modify it's elements but dont add new or removing existing ones!)
+                (only to modify it's elements but don't add new or removing existing ones!)
                 it should be possible doing so. But we must guarantee that the last operation reset
                 this lock ... not the first one ! So we use a "ref count" mechanism for that."
      */
@@ -435,8 +435,8 @@ private:
 
     /** @short  special debug option to make testing faster.
 
-        @descr  We dont interpret the timer unit as [min] ...
-                we use [ms] instead of that. Further we dont
+        @descr  We don't interpret the timer unit as [min] ...
+                we use [ms] instead of that. Further we don't
                 wait 10 s for user idle ...
      */
     #if OSL_DEBUG_LEVEL > 1
@@ -664,8 +664,8 @@ private:
                 the new document, which should be deregistered.
 
         @param  bStopListening
-                sal_False: must be used in case this method is called withion disposing() of the document,
-                       where it make no sense to deregister our listener. The container dies ...
+                sal_False: must be used in case this method is called within disposing() of the document,
+                       where it make no sense to deregister our listener. The container dies...
                 sal_True : must be used in case this method is used on "dergistration" of this document, where
                        we must deregister our listener .-)
 
@@ -725,7 +725,7 @@ private:
                              If a document is the most active one, saving it
                              will be postponed if there exists other unsaved
                              documents. This feature was implemented, because
-                             we dont wish to disturb the user on it's work.
+                             we don't wish to disturb the user on it's work.
                              ... bAllowUserIdleLoop should be set to sal_True
                 EMERGENCY_SAVE / SESSION_SAVE =>
                              Here we must finish our work ASAP! It's not allowed
@@ -963,7 +963,7 @@ private:
         @descr  The problem behind: There exists different use case of this method.
                 a) An external progress is provided by our CrashSave or Recovery dialog.
                 b) We must create our own progress e.g. for an AutoSave
-                c) Sometimes our application filters dont use the progress
+                c) Sometimes our application filters don't use the progress
                    provided by the MediaDescriptor. They use the Frame every time to create
                    it's own progress. So we implemented a HACK for these and now we set
                    an InterceptedProgress there for the time WE use this frame for loading/storing documents .-)
@@ -993,12 +993,12 @@ private:
         Every URL supported by our UCB component can be used here.
         Further it doesn't matter if the file really exists or not.
         Because removing a non exsistent file will have the same
-        result at the end ... a non existing file .-)
+        result at the end... a non existing file .-)
 
         On the other side removing of files from disc is an optional
-        feature. If we are not able doing so ... its not a real problem.
-        Ok - users disc place will be samller then ... but we should produce
-        a crash during crash save because we can't delete a temporary file only !
+        feature. If we are not able doing so... its not a real problem.
+        Ok - users disc place will be smaller then... but we should produce
+        a crash during crash save because we can't delete a temporary file only!
 
         @param  sURL
                 the url of the file, which should be removed.
@@ -1360,7 +1360,7 @@ void SAL_CALL AutoRecovery::dispatch(const css::util::URL&
         bool bOn = lArgs.getUnpackedValueOrDefault(PROP_AUTOSAVE_STATE, true);
         if (bOn)
         {
             // dont enable AutoSave hardly !
             // reload configuration to know the current state.
             implts_readAutoSaveConfig();
             implts_updateTimer();
@@ -1744,7 +1744,7 @@ void SAL_CALL AutoRecovery::disposing(const css::lang::EventObject& aEvent)
     css::uno::Reference< css::frame::XModel > xDocument(aEvent.Source, css::uno::UNO_QUERY);
     if (xDocument.is())
     {
-        implts_deregisterDocument(xDocument, false); // sal_False => dont call removeEventListener() .. because it's not needed here
+        implts_deregisterDocument(xDocument, false); // sal_False => don't call removeEventListener() .. because it's not needed here
         return;
     }
 
@@ -2225,7 +2225,7 @@ void AutoRecovery::implts_stopListening()
     /* SAFE */ {
     osl::MutexGuard g(cppu::WeakComponentImplHelperBase::rBHelper.rMutex);
     // Attention: Dont reset our internal members here too.
     // May be we must work with our configuration, but dont wish to be informed
     // about changes any longer. Needed e.g. during EMERGENCY_SAVE!
     xCFG.set                   (m_xRecoveryCFG      , css::uno::UNO_QUERY);
     xGlobalEventBroadcaster.set(m_xNewDocBroadcaster, css::uno::UNO_QUERY);
@@ -2451,7 +2451,7 @@ void AutoRecovery::implts_registerDocument(const css::uno::Reference< css::frame
     // Can happen if events came in asynchronous on recovery time.
     // Then our cache was filled from the configuration ... but now we get some
     // asynchronous events from the global event broadcaster. We must be sure that
     // we dont add the same document more than once.
     AutoRecovery::TDocumentList::iterator pIt = AutoRecovery::impl_searchDocument(m_lDocCache, xDocument);
     if (pIt != m_lDocCache.end())
     {
@@ -2467,7 +2467,7 @@ void AutoRecovery::implts_registerDocument(const css::uno::Reference< css::frame
     utl::MediaDescriptor lDescriptor(xDocument->getArgs());
 
     // check if this document must be ignored for recovery !
     // Some use cases dont wish support for AutoSave/Recovery ... as e.g. OLE-Server / ActiveX Control etcpp.
     bool bNoAutoSave = lDescriptor.getUnpackedValueOrDefault(utl::MediaDescriptor::PROP_NOAUTOSAVE(), false);
     if (bNoAutoSave)
         return;
@@ -2619,7 +2619,7 @@ void AutoRecovery::implts_markDocumentModifiedAgainstLastBackup(const css::uno::
     if (pIt != m_lDocCache.end())
     {
         /* Now we know, that this document was modified again and must be saved next time.
-           But we dont need this information for every e.g. key input of the user.
+           But we don't need this information for every e.g. key input of the user.
            So we stop listening here.
            But if the document was saved as temp. file we start listening for this event again.
         */
@@ -2949,7 +2949,7 @@ AutoRecovery::ETimerType AutoRecovery::implts_saveDocs(       bool        bAllow
 
         // already auto saved during this session :-)
         // This state must be reset for all documents
-        // if timer is started with normnal AutoSaveTimerIntervall!
+        // if timer is started with normal AutoSaveTimerIntervall!
         if ((aInfo.DocumentState & AutoRecovery::E_HANDLED) == AutoRecovery::E_HANDLED)
             continue;
 
@@ -3231,7 +3231,7 @@ AutoRecovery::ETimerType AutoRecovery::implts_openDocs(const DispatchParams& aPa
         // a1,b1,c1,d2,e2,f2)
         if ((rInfo.DocumentState & AutoRecovery::E_DAMAGED) == AutoRecovery::E_DAMAGED)
         {
             // dont forget to inform listener! May be this document was
             // damaged on last saving time ...
             // Then our listener need this notification.
             // If it was damaged during last "try to open" ...
@@ -3268,7 +3268,7 @@ AutoRecovery::ETimerType AutoRecovery::implts_openDocs(const DispatchParams& aPa
             if (!bOriginalWasTried)
             {
                 rInfo.DocumentState |= AutoRecovery::E_INCOMPLETE;
                 // try original URL ... ! dont continue with next item here ...
             }
             else
             {
@@ -3384,7 +3384,7 @@ AutoRecovery::ETimerType AutoRecovery::implts_openDocs(const DispatchParams& aPa
            since our last AutoSave. And we deregister us in case we know this state.
            But directly after one document as recovered ... we must start listening.
            Otherwhise the first "modify" doesn't reach us. Because we ourself called setModified()
-           on the document via API. And currently we dont listen for any events (not at theGlobalEventBroadcaster
+           on the document via API. And currently we don't listen for any events (not at theGlobalEventBroadcaster
            nor at any document!).
         */
         implts_startModifyListeningOnDoc(rInfo);
@@ -3528,7 +3528,7 @@ void AutoRecovery::implts_generateNewTempURL(const OUString&               sBack
     // In case we are asked to save unmodified documents too - and one of them
     // is an empty one (because it was new created using e.g. an URL private:factory/...)
     // we should not save it really. Then we put the information about such "empty document"
     // into the configuration and dont create any recovery file on disk.
     // We use the title of the document to make it unique.
     OUStringBuffer sUniqueName;
     if (!rInfo.OrgURL.isEmpty())
@@ -3710,7 +3710,7 @@ void AutoRecovery::implts_prepareEmergencySave()
 
 void AutoRecovery::implts_doEmergencySave(const DispatchParams& aParams)
 {
-    // Write a hint "we chrashed" into the configuration, so
+    // Write a hint "we crashed" into the configuration, so
     // the error report tool is started too in case no recovery
     // documents exists and was saved.
     ::comphelper::ConfigurationHelper::writeDirectKey(
@@ -3832,7 +3832,7 @@ void AutoRecovery::implts_doSessionQuietQuit(const DispatchParams& /*aParams*/)
     // confusing for the user
     AutoRecovery::st_impl_removeLockFile();
 
-    // reset all modified documents, so the dont show any UI on closing ...
+    // reset all modified documents, so the don't show any UI on closing ...
     // and close all documents, so we can shutdown the OS!
     implts_prepareSessionShutdown();
 
@@ -4237,7 +4237,7 @@ void AutoRecovery::impl_establishProgress(const AutoRecovery::TDocumentInfo&
                                                                                 css::uno::Reference< css::task::XStatusIndicator >() );
 
     // Normally a progress is set from outside (e.g. by the CrashSave/Recovery dialog, which uses our dispatch API).
     // But for a normal auto save we dont have such "external progress"... because this function is triggered by our own timer then.
     // In such case we must create our own progress !
     if (
         (! xExternalProgress.is()) &&
@@ -234,7 +234,7 @@ public:
             to poll for the end of an user action, which does not allow saving documents in general */
         E_POLL_TILL_AUTOSAVE_IS_ALLOWED,
-        /** dont start the timer - but calls the same action then before immediately again! */
+        /** don't start the timer - but calls the same action then before immediately again! */
         E_CALL_ME_BACK
     };
@@ -1360,7 +1360,7 @@ void SAL_CALL AutoRecovery::dispatch(const css::util::URL&
         if (bOn)
         {
-            // dont enable AutoSave hardly !
+            // don't enable AutoSave hardly !
             // reload configuration to know the current state.
             implts_readAutoSaveConfig();
@@ -2225,7 +2225,7 @@ void AutoRecovery::implts_stopListening()
     osl::MutexGuard g(cppu::WeakComponentImplHelperBase::rBHelper.rMutex);
     // Attention: Dont reset our internal members here too.
-    // May be we must work with our configuration, but dont wish to be informed
+    // May be we must work with our configuration, but don't wish to be informed
     // about changes any longer. Needed e.g. during EMERGENCY_SAVE!
     xCFG.set                   (m_xRecoveryCFG      , css::uno::UNO_QUERY);
@@ -2451,7 +2451,7 @@ void AutoRecovery::implts_registerDocument(const css::uno::Reference< css::frame
     // Then our cache was filled from the configuration ... but now we get some
     // asynchronous events from the global event broadcaster. We must be sure that
-    // we dont add the same document more than once.
+    // we don't add the same document more than once.
     AutoRecovery::TDocumentList::iterator pIt = AutoRecovery::impl_searchDocument(m_lDocCache, xDocument);
     if (pIt != m_lDocCache.end())
@@ -2467,7 +2467,7 @@ void AutoRecovery::implts_registerDocument(const css::uno::Reference< css::frame
 
     // check if this document must be ignored for recovery !
-    // Some use cases dont wish support for AutoSave/Recovery ... as e.g. OLE-Server / ActiveX Control etcpp.
+    // Some use cases don't wish support for AutoSave/Recovery ... as e.g. OLE-Server / ActiveX Control etcpp.
     bool bNoAutoSave = lDescriptor.getUnpackedValueOrDefault(utl::MediaDescriptor::PROP_NOAUTOSAVE(), false);
     if (bNoAutoSave)
@@ -3231,7 +3231,7 @@ AutoRecovery::ETimerType AutoRecovery::implts_openDocs(const DispatchParams& aPa
         if ((rInfo.DocumentState & AutoRecovery::E_DAMAGED) == AutoRecovery::E_DAMAGED)
         {
-            // dont forget to inform listener! May be this document was
+            // don't forget to inform listener! May be this document was
             // damaged on last saving time ...
             // Then our listener need this notification.
@@ -3268,7 +3268,7 @@ AutoRecovery::ETimerType AutoRecovery::implts_openDocs(const DispatchParams& aPa
             {
                 rInfo.DocumentState |= AutoRecovery::E_INCOMPLETE;
-                // try original URL ... ! dont continue with next item here ...
+                // try original URL ... ! don't continue with next item here ...
             }
             else
@@ -3528,7 +3528,7 @@ void AutoRecovery::implts_generateNewTempURL(const OUString&               sBack
     // is an empty one (because it was new created using e.g. an URL private:factory/...)
     // we should not save it really. Then we put the information about such "empty document"
-    // into the configuration and dont create any recovery file on disk.
+    // into the configuration and don't create any recovery file on disk.
     // We use the title of the document to make it unique.
     OUStringBuffer sUniqueName;
@@ -4237,7 +4237,7 @@ void AutoRecovery::impl_establishProgress(const AutoRecovery::TDocumentInfo&
 
     // Normally a progress is set from outside (e.g. by the CrashSave/Recovery dialog, which uses our dispatch API).
-    // But for a normal auto save we dont have such "external progress"... because this function is triggered by our own timer then.
+    // But for a normal auto save we don't have such "external progress"... because this function is triggered by our own timer then.
     // In such case we must create our own progress !
     if (